# VeraMind

**VeraMind** is a fine-tuned machine learning model designed to predict whether a news article is real or fake. Built using the Hugging Face Transformers library and PyTorch, the `VeraMind-Mini` model is optimized for binary text classification tasks.



## Features

- **Real or Fake Prediction**: Classifies news articles as "REAL" or "FAKE."
- **Confidence Score**: Provides a numerical confidence score for each prediction.
- **Fine-Tuned Model**: Uses `VeraMind-Mini`, a fine-tuned version of [fabelous-albert-uncased](https://gitea.fabelous.app/Fabel/Fabelous-albert-uncased), for robust and reliable predictions.



## Downloading the Model

You can download the `VeraMind-Mini` model from the following link:

[Download VeraMind-Mini Model](https://gitea.fabelous.app/Fabel/VeraMind/releases/download/latest/VeraMind-Mini.zip)



## Usage Example

The example below demonstrates how to use the `VeraMindInference` class to evaluate the authenticity of a news article:

```python
from src.Inference import VeraMindInference

# Load the model
model = VeraMindInference("path/to/VeraMind-Mini")

# Example news article text
text = "This is an example News Article"

# Predict if the news is real or fake
result = model.predict(text)

print(result)
```

Output:

```python
{'result': 'FAKE', 'confidence': 0.9990140199661255}
```



## Disclaimer

This project is provided "as-is" without any warranties. While the model strives for accuracy, it may make mistakes. Always verify predictions by consulting multiple reliable sources. Use this tool responsibly.



## License

This project is licensed under the [Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International (CC BY-NC-ND 4.0)](https://creativecommons.org/licenses/by-nc-nd/4.0/). You may use and share this software privately, but must credit the authors, refrain from commercial use, and avoid creating derivative works.

## Feedback and Support

If you encounter any issues or have questions, feel free to reach out through the project's [Gitea Issues page](https://gitea.fabelous.app/Fabel/Fabelous-albert-uncased/issues) or contact our support team at support@fabelous.app.